function sfun_inferenz(block)
  % S-Funktion für die SUM-PROD-Inferenz
  % Eingänge: Fuzzyvektoren E1, E2
  % Ausgang: Fuzzyvektor A
  % Parameter: Regelmatrix M
  setup(block);
end
  
%% -------------------------------------------------------------------
function setup(block)
  % Zahl der Anschlüsse
  block.NumInputPorts  = 2;
  block.NumOutputPorts = 1;
  block.NumDialogPrms = 1;

  % Größen aus Parameter
  M = block.DialogPrm(1).Data;   % Regelmatrix
  N = max(max(M));               % Größe des Ausgangsvektors
  
  % Konfiguration der Anschlüsse
  block.SetPreCompInpPortInfoToDynamic;
  block.SetPreCompOutPortInfoToDynamic;
  block.InputPort(1).Dimensions = size(M,1);
  block.InputPort(2).Dimensions = size(M,2);
  block.OutputPort(1).Dimensions = N;
  block.SampleTimes = [-1 0];

  % Callbacks
  block.RegBlockMethod('Outputs', @Outputs);
end
%% -------------------------------------------------------------------------
function Outputs(block)
  M = block.DialogPrm(1).Data;   % Regelmatrix
  N = max(max(M));               % Größe des Ausgangsvektors
  E1 = block.InputPort(1).Data;  % Fuzzyvektor E1
  E2 = block.InputPort(2).Data;  % Fuzzyvektor E2
  
  A = zeros(1,N);
  for I = 1:N
    M0 = (M == I);
    A(I) = dot(E1, M0*E2);
  end
  
  block.OutputPort(1).Data = A;
end